==> ud1_1.zip: js/ardoraEWMenu.js <==
$(function(){
      $(".fg-button").hover(
          function(){ $(this).removeClass("ui-state-default").addClass("ui-state-focus"); },
      	   function(){ $(this).removeClass("ui-state-focus").addClass("ui-state-default"); }
       );
   $("#flat0").menu({
       content: $("#flat0").next().html(),
       showSpeed: 400,
       flyOut: true
   });
   $("#flat5").menu({
       content: $("#flat5").next().html(),
       showSpeed: 400,
       flyOut: true
   });
   $("#flat8").menu({
       content: $("#flat8").next().html(),
       showSpeed: 400,
       flyOut: true
   });
   $("#flat9").menu({
       content: $("#flat9").next().html(),
       showSpeed: 400,
       flyOut: true
   });
   $("#flat12").menu({
       content: $("#flat12").next().html(),
       showSpeed: 400,
       flyOut: true
   });
   $("#flat16").menu({
       content: $("#flat16").next().html(),
       showSpeed: 400,
       flyOut: true
   });
   $("#flat20").menu({
       content: $("#flat20").next().html(),
       showSpeed: 400,
       flyOut: true
   });
   $("#flat28").menu({
       content: $("#flat28").next().html(),
       showSpeed: 400,
       flyOut: true
   });
   $("#flat36").menu({
       content: $("#flat36").next().html(),
       showSpeed: 400,
       flyOut: true
   });
   $("#flat40").menu({
       content: $("#flat40").next().html(),
       showSpeed: 400,
       flyOut: true
   });
   $("#flat46").menu({
       content: $("#flat46").next().html(),
       showSpeed: 400,
       flyOut: true
   });
   $("#flat56").menu({
       content: $("#flat56").next().html(),
       showSpeed: 400,
       flyOut: true
   });
   $("#flat58").menu({
       content: $("#flat58").next().html(),
       showSpeed: 400,
       flyOut: true
   });
   $("#flat63").menu({
       content: $("#flat63").next().html(),
       showSpeed: 400,
       flyOut: true
   });
   $("#flat68").menu({
       content: $("#flat68").next().html(),
       showSpeed: 400,
       flyOut: true
   });
   $("#flat70").menu({
       content: $("#flat70").next().html(),
       showSpeed: 400,
       flyOut: true
   });
   $("#flat73").menu({
       content: $("#flat73").next().html(),
       showSpeed: 400,
       flyOut: true
   });
   $("#flat80").menu({
       content: $("#flat80").next().html(),
       showSpeed: 400,
       flyOut: true
   });
   $("#flat85").menu({
       content: $("#flat85").next().html(),
       showSpeed: 400,
       flyOut: true
   });
});
function cargar(url){
var iframe = document.getElementById("showIframe");
iframe.src = url;
$("#showIframe").load(function() {$(this).contents().find("body").css({"text-align":"inherit"});});
}
function cargarIma(url){
var iframe = document.getElementById("showIframe");
iframe.src = url;
$("#showIframe").load(function() {$(this).contents().find("body").css({"text-align":"center"});});
}

==> ud2_0.zip: js/ardoraEWMenu.js <==
$(function(){
      $(".fg-button").hover(
          function(){ $(this).removeClass("ui-state-default").addClass("ui-state-focus"); },
      	   function(){ $(this).removeClass("ui-state-focus").addClass("ui-state-default"); }
       );
   $("#flat0").menu({
       content: $("#flat0").next().html(),
       showSpeed: 400,
       flyOut: true
   });
   $("#flat5").menu({
       content: $("#flat5").next().html(),
       showSpeed: 400,
       flyOut: true
   });
   $("#flat8").menu({
       content: $("#flat8").next().html(),
       showSpeed: 400,
       flyOut: true
   });
   $("#flat12").menu({
       content: $("#flat12").next().html(),
       showSpeed: 400,
       flyOut: true
   });
   $("#flat13").menu({
       content: $("#flat13").next().html(),
       showSpeed: 400,
       flyOut: true
   });
   $("#flat24").menu({
       content: $("#flat24").next().html(),
       showSpeed: 400,
       flyOut: true
   });
   $("#flat27").menu({
       content: $("#flat27").next().html(),
       showSpeed: 400,
       flyOut: true
   });
   $("#flat32").menu({
       content: $("#flat32").next().html(),
       showSpeed: 400,
       flyOut: true
   });
   $("#flat37").menu({
       content: $("#flat37").next().html(),
       showSpeed: 400,
       flyOut: true
   });
   $("#flat40").menu({
       content: $("#flat40").next().html(),
       showSpeed: 400,
       flyOut: true
   });
   $("#flat48").menu({
       content: $("#flat48").next().html(),
       showSpeed: 400,
       flyOut: true
   });
   $("#flat51").menu({
       content: $("#flat51").next().html(),
       showSpeed: 400,
       flyOut: true
   });
   $("#flat57").menu({
       content: $("#flat57").next().html(),
       showSpeed: 400,
       flyOut: true
   });
   $("#flat64").menu({
       content: $("#flat64").next().html(),
       showSpeed: 400,
       flyOut: true
   });
});
function cargar(url){
var iframe = document.getElementById("showIframe");
iframe.src = url;
$("#showIframe").on("load",function() {$(this).contents().find("body").css({"text-align":"inherit"});});
}
function cargarIma(url){
var iframe = document.getElementById("showIframe");
iframe.src = url;
$("#showIframe").on("load",function() {$(this).contents().find("body").css({"text-align":"center"});});
}
